@@ -10,31 +10,6 @@
         <source>MX Cleanup</source>
         <translation>MX Takarító</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="696"/>
-        <source>Clean Flatpak</source>
-        <translation>Flatpak takarítás</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="702"/>
-        <source>Remove unused runtimes</source>
-        <translation>Nem használt környezetek eltávolítása</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="718"/>
-        <source>Clean Folders</source>
-        <translation>Mappák takarítása</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="737"/>
-        <source>Not accessed for:</source>
-        <translation>Ennyi ideje nem volt elérve:</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="805"/>
-        <source>All (potentially dangerous)</source>
-        <translation>Mind (potenciálisan veszélyes)</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="59"/>
         <source>Display help </source>
@@ -113,10 +88,6 @@
         <source> days</source>
         <translation>nap</translation>
     </message>
-    <message>
-        <source>Not accessed for</source>
-        <translation type="vanished">Ennyi ideje nem volt elérve:</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="264"/>
         <source>All users</source>
@@ -228,6 +199,31 @@
         <source>List and select kernels to remove</source>
         <translation>Az eltávolítandó kernelek kilistázása és kiválasztása</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="696"/>
+        <source>Clean Flatpak</source>
+        <translation>Flatpak takarítás</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="702"/>
+        <source>Remove unused runtimes</source>
+        <translation>Nem használt környezetek eltávolítása</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="718"/>
+        <source>Clean Folders</source>
+        <translation>Mappák takarítása</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="737"/>
+        <source>Not accessed for:</source>
+        <translation>Ennyi ideje nem volt elérve:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="805"/>
+        <source>All (potentially dangerous)</source>
+        <translation>Mind (potenciálisan veszélyes)</translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="335"/>
         <location filename="../mainwindow.cpp" line="339"/>
@@ -280,22 +276,6 @@
         <source>%1 Help</source>
         <translation>%1 Súgó</translation>
     </message>
-    <message>
-        <source>License</source>
-        <translation type="vanished">Licenc</translation>
-    </message>
-    <message>
-        <source>Changelog</source>
-        <translation type="vanished">Változások listája</translation>
-    </message>
-    <message>
-        <source>Cancel</source>
-        <translation type="vanished">Mégsem</translation>
-    </message>
-    <message>
-        <source>&amp;Close</source>
-        <translation type="vanished">&amp;Bezárás</translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="536"/>
         <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
@@ -324,21 +304,6 @@
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <location filename="../main.cpp" line="51"/>
-        <source>Quick safe removal of old files</source>
-        <translation>A régi fájlok gyors és biztonságos eltávolítása</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="74"/>
-        <source>Error</source>
-        <translation>Hiba</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="75"/>
-        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
-        <translation>Úgy tűnik, hogy root felhasználóként van bejelentkezve. Jelentkezzen ki és jelentkezzen be normál felhasználóként a program használatához.</translation>
-    </message>
     <message>
         <location filename="../about.cpp" line="52"/>
         <source>License</source>
@@ -360,5 +325,20 @@
         <source>&amp;Close</source>
         <translation>&amp;Bezárás</translation>
     </message>
+    <message>
+        <location filename="../main.cpp" line="51"/>
+        <source>Quick safe removal of old files</source>
+        <translation>A régi fájlok gyors és biztonságos eltávolítása</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="74"/>
+        <source>Error</source>
+        <translation>Hiba</translation>
+    </message>
+    <message>
+        <location filename="../main.cpp" line="75"/>
+        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
+        <translation>Úgy tűnik, hogy root felhasználóként van bejelentkezve. Jelentkezzen ki és jelentkezzen be normál felhasználóként a program használatához.</translation>
+    </message>
 </context>
 </TS>
